package eap.parfile.doc;

import javax.xml.parsers.*;
import org.xml.sax.*;
import org.w3c.dom.*;
import javax.xml.transform.*;
import javax.xml.transform.dom.*;
import javax.xml.transform.stream.*;


import java.io.*;

/*************************************************************************
*
*************************************************************************/
public class Stylizer {
    // Global value so it can be ref'd by the tree-adapter


public static void main (String args[]) {

    /*************************
    * check the command line *
    *************************/
    if (args.length != 2) {
        System.err.println ("Usage: java Stylizer stylesheet xmlfile");
        System.exit (1);
    }
    
    File stylesheet = new File(args[0]);
    File datafile   = new File(args[1]);


    try {
        /********************
        * read the XML file *
        ********************/
        DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
        DocumentBuilder builder = factory.newDocumentBuilder();
        Document document = builder.parse(datafile);


        /***********************
        * modify the structure *
        ***********************/

        /***************************
        * find the parameters list *
        ***************************/
        NodeList list = document.getElementsByTagName("PARAMETERS");
        if(list.getLength() != 1) {
            System.err.println("Found "+list.getLength()+" PARAMETER lists");
            System.exit(1);
        }

        Node parameters = list.item(0);

        /**************************************
        * loop over all the parameter entries *
        **************************************/
        for(Node param = parameters.getFirstChild(); param != null;
            param = param.getNextSibling() ) {

           if(!param.getNodeName().equals("PARAM")    ) continue;
           if( param.getNodeType() !=Node.ELEMENT_NODE) continue;

            Element name = (Element)((Element)param).getElementsByTagName("NAME").item(0);

            System.out.println(name.getFirstChild().getNodeValue());
            

            /******************************************
            * create a new element to hold the format *
            ******************************************/
            Element format = document.createElement("FORMAT");
            format.appendChild(document.createTextNode("hohoho"));

            
            /*****************************
            * insert after the NAME node *
            *****************************/
            param.insertBefore(format  , name.getNextSibling());

            
        }



        



        /**********************
        * read the stylesheet *
        **********************/

        TransformerFactory tFactory = TransformerFactory.newInstance();
        StreamSource stylesource = new StreamSource(stylesheet);
        Transformer transformer = tFactory.newTransformer(stylesource);

        /*************************
        * transform the document *
        *************************/
        DOMSource source = new DOMSource(document);
        StreamResult result = new StreamResult(System.out);
        transformer.transform(source, result);

    } catch (TransformerConfigurationException tce) {
    // Error generated by the parser
    System.out.println ("\n** Transformer Factory error");
    System.out.println("   " + tce.getMessage() );

    // Use the contained exception, if any
    Throwable x = tce;
    if (tce.getException() != null)
        x = tce.getException();
    x.printStackTrace();

    } catch (TransformerException te) {
    // Error generated by the parser
    System.out.println ("\n** Transformation error");
    System.out.println("   " + te.getMessage() );

    // Use the contained exception, if any
    Throwable x = te;
    if (te.getException() != null)
        x = te.getException();
    x.printStackTrace();

    } catch (SAXException sxe) {
    // Error generated by this application
    // (or a parser-initialization error)
    Exception  x = sxe;
    if (sxe.getException() != null)
        x = sxe.getException();
    x.printStackTrace();

    } catch (ParserConfigurationException pce) {
        // Parser with specified options can't be built
        pce.printStackTrace();

    } catch (IOException ioe) {
    // I/O error
    ioe.printStackTrace();
    }

} // main

}
